@@ -12,8 +12,8 @@ from yaml import safe_load, safe_dump
 
 from ocrd_validators import OcrdResourceListValidator
 from ocrd_utils import getLogger
-from ocrd_utils.constants import HOME, XDG_DATA_HOME, XDG_CONFIG_HOME
 from ocrd_utils.os import list_all_resources, pushd_popd
+from ocrd_utils.constants import XDG_CONFIG_HOME, XDG_DATA_HOME
 
 from .constants import RESOURCE_LIST_FILENAME, RESOURCE_USER_LIST_COMMENT
 
@@ -97,7 +97,8 @@ class OcrdResourceManager():
             user_database = safe_load(f) or {}
         if executable not in user_database:
             user_database[executable] = []
-        if not self.find_resources(executable=executable, name=res_name, database=user_database):
+        resources_found = self.find_resources(executable=executable, name=res_name, database=user_database)
+        if not resources_found:
             resdict = {
                 'name': res_name,
                 'url': url if url else '???',
@@ -106,6 +107,8 @@ class OcrdResourceManager():
                 'size': res_size
             }
             user_database[executable].append(resdict)
+        else:
+            resdict = resources_found[0]
         with open(self.user_list, 'w', encoding='utf-8') as f:
             f.write(RESOURCE_USER_LIST_COMMENT)
             f.write('\n')
